body {
  background: #ccc;
  font: normal 16px/32px "Hiragino Sans GB", "Hiragino Sans GB W3", "Microsoft YaHei", tahoma, arial, simsun;
  text-space: 1px;
  position: relative;
}

a {
  color: #F92672;
  &:hover {
    color: darken(#F92672, 5%);
  }
}

b, strong {
  color: #3c763d;
}

hr {
  border-top: 1px solid #ccc;
}

nav.navbar {
  border-radius: 0px;
  width: auto;
  & .navbar-nav:first-child li {
    width: 100px;
  }
}

code {
  color: #66D9EF;
  background-color: #333;
  border-radius: 5px;
  padding: 5px 12px;
  margin: 0px 5px;
}

footer {
  background: none;
  border: none;
}

pre {
  border-color: #23241f;
  background-color: #23241f;
  font-size: 20px;
  border-radius: 10px;
}

blockquote {
  background: data-uri('/static/images/blockquote.png') no-repeat;
  padding: 20px 40px 20px 75px;
  font-style: italic;
  color: #666;
}
