{% extends "base.html" %}
{% import "_macros/posts.html" as posts %}

{% block content %}
    <h2 class="text-center">标记有<code>{{ tag }}</code>的所有文章</h2>
     {{ posts.list(site.tagged(tag)) }}
{% endblock %}