{% extends "base.html" %}
{% import "_macros/posts.html" as posts %}
{% block content %}
    {{ super() }}
    <div class="post-list">
        {{ posts.list(site.locale_posts(locale)) }}
    </div>
{% endblock %}
